# PyPetrophysics
This is a python package containing a number of common petrophysical calculations that can be quickly called upon.

# Status
![Tests](https://github.com/andymcdgeo/PyPetrophysics/workflows/Tests/badge.svg?branch=master) ![Hex.pm](https://img.shields.io/hexpm/l/plug) [![PyPI](https://img.shields.io/pypi/v/PyPetrophysics.svg)](https://pypi.org/project/PyPetrophysics/)
